@@ -31,48 +31,50 @@ from nanoarrow.c_schema import c_schema
 from nanoarrow.c_buffer import c_buffer
 from nanoarrow.extension_canonical import bool8
 from nanoarrow.schema import (
-    Schema,
-    Type,
-    TimeUnit,
-    null,
+    binary_view,
+    binary,
     bool_,
-    int8,
-    uint8,
-    int16,
-    uint16,
-    int32,
-    uint32,
-    int64,
-    uint64,
+    date32,
+    date64,
+    decimal128,
+    decimal256,
+    dense_union,
+    dictionary,
+    duration,
+    extension_type,
+    fixed_size_binary,
+    fixed_size_list,
     float16,
     float32,
     float64,
-    string,
-    large_string,
-    string_view,
-    list_,
-    large_list,
-    fixed_size_list,
-    map_,
-    dictionary,
-    binary,
+    int16,
+    int32,
+    int64,
+    int8,
+    interval_day_time,
+    interval_month_day_nano,
+    interval_months,
     large_binary,
-    binary_view,
-    fixed_size_binary,
-    date32,
-    date64,
+    large_list,
+    large_string,
+    list_,
+    map_,
+    null,
+    schema,
+    Schema,
+    sparse_union,
+    string_view,
+    string,
+    struct,
     time32,
     time64,
     timestamp,
-    extension_type,
-    duration,
-    interval_months,
-    interval_day_time,
-    interval_month_day_nano,
-    decimal128,
-    decimal256,
-    schema,
-    struct,
+    TimeUnit,
+    Type,
+    uint16,
+    uint32,
+    uint64,
+    uint8,
 )
 from nanoarrow.array import array, Array
 from nanoarrow.array_stream import ArrayStream
@@ -81,17 +83,16 @@ from nanoarrow._version import __version__  # noqa: F401
 
 # Helps Sphinx automatically populate an API reference section
 __all__ = [
+    "array",
+    "Array",
     "ArrayStream",
-    "Schema",
-    "TimeUnit",
-    "Type",
-    "binary",
     "binary_view",
+    "binary",
     "bool_",
     "bool8",
-    "c_array",
     "c_array_from_buffers",
     "c_array_stream",
+    "c_array",
     "c_buffer",
     "c_schema",
     "c_version",
@@ -99,6 +100,7 @@ __all__ = [
     "date64",
     "decimal128",
     "decimal256",
+    "dense_union",
     "dictionary",
     "duration",
     "extension_type",
@@ -115,25 +117,27 @@ __all__ = [
     "interval_month_day_nano",
     "interval_months",
     "large_binary",
-    "large_string",
     "large_list",
+    "large_string",
     "list_",
     "map_",
     "null",
     "nulls_as_sentinel",
     "nulls_forbid",
     "nulls_separate",
-    "string",
-    "string_view",
-    "struct",
     "schema",
+    "Schema",
+    "sparse_union",
+    "string_view",
+    "string",
+    "struct",
     "time32",
     "time64",
     "timestamp",
+    "TimeUnit",
+    "Type",
     "uint16",
     "uint32",
     "uint64",
     "uint8",
-    "Array",
-    "array",
 ]
